# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class RemoteSubtitleInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'three_letter_iso_language_name': 'str',
        'id': 'str',
        'provider_name': 'str',
        'name': 'str',
        'format': 'str',
        'author': 'str',
        'comment': 'str',
        'date_created': 'datetime',
        'community_rating': 'float',
        'download_count': 'int',
        'is_hash_match': 'bool',
        'is_forced': 'bool',
        'is_hearing_impaired': 'bool',
        'language': 'str'
    }

    attribute_map = {
        'three_letter_iso_language_name': 'ThreeLetterISOLanguageName',
        'id': 'Id',
        'provider_name': 'ProviderName',
        'name': 'Name',
        'format': 'Format',
        'author': 'Author',
        'comment': 'Comment',
        'date_created': 'DateCreated',
        'community_rating': 'CommunityRating',
        'download_count': 'DownloadCount',
        'is_hash_match': 'IsHashMatch',
        'is_forced': 'IsForced',
        'is_hearing_impaired': 'IsHearingImpaired',
        'language': 'Language'
    }

    def __init__(self, three_letter_iso_language_name=None, id=None, provider_name=None, name=None, format=None, author=None, comment=None, date_created=None, community_rating=None, download_count=None, is_hash_match=None, is_forced=None, is_hearing_impaired=None, language=None):  # noqa: E501
        """RemoteSubtitleInfo - a model defined in Swagger"""  # noqa: E501
        self._three_letter_iso_language_name = None
        self._id = None
        self._provider_name = None
        self._name = None
        self._format = None
        self._author = None
        self._comment = None
        self._date_created = None
        self._community_rating = None
        self._download_count = None
        self._is_hash_match = None
        self._is_forced = None
        self._is_hearing_impaired = None
        self._language = None
        self.discriminator = None
        if three_letter_iso_language_name is not None:
            self.three_letter_iso_language_name = three_letter_iso_language_name
        if id is not None:
            self.id = id
        if provider_name is not None:
            self.provider_name = provider_name
        if name is not None:
            self.name = name
        if format is not None:
            self.format = format
        if author is not None:
            self.author = author
        if comment is not None:
            self.comment = comment
        if date_created is not None:
            self.date_created = date_created
        if community_rating is not None:
            self.community_rating = community_rating
        if download_count is not None:
            self.download_count = download_count
        if is_hash_match is not None:
            self.is_hash_match = is_hash_match
        if is_forced is not None:
            self.is_forced = is_forced
        if is_hearing_impaired is not None:
            self.is_hearing_impaired = is_hearing_impaired
        if language is not None:
            self.language = language

    @property
    def three_letter_iso_language_name(self):
        """Gets the three_letter_iso_language_name of this RemoteSubtitleInfo.  # noqa: E501

        Use language instead to return the language specified by the subtitle provider  # noqa: E501

        :return: The three_letter_iso_language_name of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._three_letter_iso_language_name

    @three_letter_iso_language_name.setter
    def three_letter_iso_language_name(self, three_letter_iso_language_name):
        """Sets the three_letter_iso_language_name of this RemoteSubtitleInfo.

        Use language instead to return the language specified by the subtitle provider  # noqa: E501

        :param three_letter_iso_language_name: The three_letter_iso_language_name of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._three_letter_iso_language_name = three_letter_iso_language_name

    @property
    def id(self):
        """Gets the id of this RemoteSubtitleInfo.  # noqa: E501


        :return: The id of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RemoteSubtitleInfo.


        :param id: The id of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def provider_name(self):
        """Gets the provider_name of this RemoteSubtitleInfo.  # noqa: E501


        :return: The provider_name of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """Sets the provider_name of this RemoteSubtitleInfo.


        :param provider_name: The provider_name of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._provider_name = provider_name

    @property
    def name(self):
        """Gets the name of this RemoteSubtitleInfo.  # noqa: E501


        :return: The name of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RemoteSubtitleInfo.


        :param name: The name of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def format(self):
        """Gets the format of this RemoteSubtitleInfo.  # noqa: E501


        :return: The format of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this RemoteSubtitleInfo.


        :param format: The format of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def author(self):
        """Gets the author of this RemoteSubtitleInfo.  # noqa: E501


        :return: The author of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this RemoteSubtitleInfo.


        :param author: The author of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def comment(self):
        """Gets the comment of this RemoteSubtitleInfo.  # noqa: E501


        :return: The comment of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this RemoteSubtitleInfo.


        :param comment: The comment of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def date_created(self):
        """Gets the date_created of this RemoteSubtitleInfo.  # noqa: E501


        :return: The date_created of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this RemoteSubtitleInfo.


        :param date_created: The date_created of this RemoteSubtitleInfo.  # noqa: E501
        :type: datetime
        """

        self._date_created = date_created

    @property
    def community_rating(self):
        """Gets the community_rating of this RemoteSubtitleInfo.  # noqa: E501


        :return: The community_rating of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: float
        """
        return self._community_rating

    @community_rating.setter
    def community_rating(self, community_rating):
        """Sets the community_rating of this RemoteSubtitleInfo.


        :param community_rating: The community_rating of this RemoteSubtitleInfo.  # noqa: E501
        :type: float
        """

        self._community_rating = community_rating

    @property
    def download_count(self):
        """Gets the download_count of this RemoteSubtitleInfo.  # noqa: E501


        :return: The download_count of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: int
        """
        return self._download_count

    @download_count.setter
    def download_count(self, download_count):
        """Sets the download_count of this RemoteSubtitleInfo.


        :param download_count: The download_count of this RemoteSubtitleInfo.  # noqa: E501
        :type: int
        """

        self._download_count = download_count

    @property
    def is_hash_match(self):
        """Gets the is_hash_match of this RemoteSubtitleInfo.  # noqa: E501


        :return: The is_hash_match of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_hash_match

    @is_hash_match.setter
    def is_hash_match(self, is_hash_match):
        """Sets the is_hash_match of this RemoteSubtitleInfo.


        :param is_hash_match: The is_hash_match of this RemoteSubtitleInfo.  # noqa: E501
        :type: bool
        """

        self._is_hash_match = is_hash_match

    @property
    def is_forced(self):
        """Gets the is_forced of this RemoteSubtitleInfo.  # noqa: E501


        :return: The is_forced of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_forced

    @is_forced.setter
    def is_forced(self, is_forced):
        """Sets the is_forced of this RemoteSubtitleInfo.


        :param is_forced: The is_forced of this RemoteSubtitleInfo.  # noqa: E501
        :type: bool
        """

        self._is_forced = is_forced

    @property
    def is_hearing_impaired(self):
        """Gets the is_hearing_impaired of this RemoteSubtitleInfo.  # noqa: E501


        :return: The is_hearing_impaired of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_hearing_impaired

    @is_hearing_impaired.setter
    def is_hearing_impaired(self, is_hearing_impaired):
        """Sets the is_hearing_impaired of this RemoteSubtitleInfo.


        :param is_hearing_impaired: The is_hearing_impaired of this RemoteSubtitleInfo.  # noqa: E501
        :type: bool
        """

        self._is_hearing_impaired = is_hearing_impaired

    @property
    def language(self):
        """Gets the language of this RemoteSubtitleInfo.  # noqa: E501


        :return: The language of this RemoteSubtitleInfo.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this RemoteSubtitleInfo.


        :param language: The language of this RemoteSubtitleInfo.  # noqa: E501
        :type: str
        """

        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RemoteSubtitleInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteSubtitleInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PublicSystemInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'local_address': 'str',
        'local_addresses': 'list[str]',
        'wan_address': 'str',
        'remote_addresses': 'list[str]',
        'server_name': 'str',
        'version': 'str',
        'id': 'str'
    }

    attribute_map = {
        'local_address': 'LocalAddress',
        'local_addresses': 'LocalAddresses',
        'wan_address': 'WanAddress',
        'remote_addresses': 'RemoteAddresses',
        'server_name': 'ServerName',
        'version': 'Version',
        'id': 'Id'
    }

    def __init__(self, local_address=None, local_addresses=None, wan_address=None, remote_addresses=None, server_name=None, version=None, id=None):  # noqa: E501
        """PublicSystemInfo - a model defined in Swagger"""  # noqa: E501
        self._local_address = None
        self._local_addresses = None
        self._wan_address = None
        self._remote_addresses = None
        self._server_name = None
        self._version = None
        self._id = None
        self.discriminator = None
        if local_address is not None:
            self.local_address = local_address
        if local_addresses is not None:
            self.local_addresses = local_addresses
        if wan_address is not None:
            self.wan_address = wan_address
        if remote_addresses is not None:
            self.remote_addresses = remote_addresses
        if server_name is not None:
            self.server_name = server_name
        if version is not None:
            self.version = version
        if id is not None:
            self.id = id

    @property
    def local_address(self):
        """Gets the local_address of this PublicSystemInfo.  # noqa: E501

        The local address.  # noqa: E501

        :return: The local_address of this PublicSystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._local_address

    @local_address.setter
    def local_address(self, local_address):
        """Sets the local_address of this PublicSystemInfo.

        The local address.  # noqa: E501

        :param local_address: The local_address of this PublicSystemInfo.  # noqa: E501
        :type: str
        """

        self._local_address = local_address

    @property
    def local_addresses(self):
        """Gets the local_addresses of this PublicSystemInfo.  # noqa: E501


        :return: The local_addresses of this PublicSystemInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._local_addresses

    @local_addresses.setter
    def local_addresses(self, local_addresses):
        """Sets the local_addresses of this PublicSystemInfo.


        :param local_addresses: The local_addresses of this PublicSystemInfo.  # noqa: E501
        :type: list[str]
        """

        self._local_addresses = local_addresses

    @property
    def wan_address(self):
        """Gets the wan_address of this PublicSystemInfo.  # noqa: E501

        The wan address.  # noqa: E501

        :return: The wan_address of this PublicSystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._wan_address

    @wan_address.setter
    def wan_address(self, wan_address):
        """Sets the wan_address of this PublicSystemInfo.

        The wan address.  # noqa: E501

        :param wan_address: The wan_address of this PublicSystemInfo.  # noqa: E501
        :type: str
        """

        self._wan_address = wan_address

    @property
    def remote_addresses(self):
        """Gets the remote_addresses of this PublicSystemInfo.  # noqa: E501


        :return: The remote_addresses of this PublicSystemInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._remote_addresses

    @remote_addresses.setter
    def remote_addresses(self, remote_addresses):
        """Sets the remote_addresses of this PublicSystemInfo.


        :param remote_addresses: The remote_addresses of this PublicSystemInfo.  # noqa: E501
        :type: list[str]
        """

        self._remote_addresses = remote_addresses

    @property
    def server_name(self):
        """Gets the server_name of this PublicSystemInfo.  # noqa: E501

        The name of the server.  # noqa: E501

        :return: The server_name of this PublicSystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this PublicSystemInfo.

        The name of the server.  # noqa: E501

        :param server_name: The server_name of this PublicSystemInfo.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def version(self):
        """Gets the version of this PublicSystemInfo.  # noqa: E501

        The version.  # noqa: E501

        :return: The version of this PublicSystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PublicSystemInfo.

        The version.  # noqa: E501

        :param version: The version of this PublicSystemInfo.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def id(self):
        """Gets the id of this PublicSystemInfo.  # noqa: E501

        The id.  # noqa: E501

        :return: The id of this PublicSystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicSystemInfo.

        The id.  # noqa: E501

        :param id: The id of this PublicSystemInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PublicSystemInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicSystemInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LevelInformation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'short_name': 'str',
        'description': 'str',
        'ordinal': 'int',
        'max_bit_rate': 'BitRate',
        'max_bit_rate_display': 'str',
        'id': 'str',
        'resolution_rates': 'list[ResolutionWithRate]',
        'resolution_rate_strings': 'list[str]',
        'resolution_rates_display': 'str'
    }

    attribute_map = {
        'short_name': 'ShortName',
        'description': 'Description',
        'ordinal': 'Ordinal',
        'max_bit_rate': 'MaxBitRate',
        'max_bit_rate_display': 'MaxBitRateDisplay',
        'id': 'Id',
        'resolution_rates': 'ResolutionRates',
        'resolution_rate_strings': 'ResolutionRateStrings',
        'resolution_rates_display': 'ResolutionRatesDisplay'
    }

    def __init__(self, short_name=None, description=None, ordinal=None, max_bit_rate=None, max_bit_rate_display=None, id=None, resolution_rates=None, resolution_rate_strings=None, resolution_rates_display=None):  # noqa: E501
        """LevelInformation - a model defined in Swagger"""  # noqa: E501
        self._short_name = None
        self._description = None
        self._ordinal = None
        self._max_bit_rate = None
        self._max_bit_rate_display = None
        self._id = None
        self._resolution_rates = None
        self._resolution_rate_strings = None
        self._resolution_rates_display = None
        self.discriminator = None
        if short_name is not None:
            self.short_name = short_name
        if description is not None:
            self.description = description
        if ordinal is not None:
            self.ordinal = ordinal
        if max_bit_rate is not None:
            self.max_bit_rate = max_bit_rate
        if max_bit_rate_display is not None:
            self.max_bit_rate_display = max_bit_rate_display
        if id is not None:
            self.id = id
        if resolution_rates is not None:
            self.resolution_rates = resolution_rates
        if resolution_rate_strings is not None:
            self.resolution_rate_strings = resolution_rate_strings
        if resolution_rates_display is not None:
            self.resolution_rates_display = resolution_rates_display

    @property
    def short_name(self):
        """Gets the short_name of this LevelInformation.  # noqa: E501

        The enum member name of the level.  # noqa: E501

        :return: The short_name of this LevelInformation.  # noqa: E501
        :rtype: str
        """
        return self._short_name

    @short_name.setter
    def short_name(self, short_name):
        """Sets the short_name of this LevelInformation.

        The enum member name of the level.  # noqa: E501

        :param short_name: The short_name of this LevelInformation.  # noqa: E501
        :type: str
        """

        self._short_name = short_name

    @property
    def description(self):
        """Gets the description of this LevelInformation.  # noqa: E501

        The common name of the level.  # noqa: E501

        :return: The description of this LevelInformation.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LevelInformation.

        The common name of the level.  # noqa: E501

        :param description: The description of this LevelInformation.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def ordinal(self):
        """Gets the ordinal of this LevelInformation.  # noqa: E501

        A value indicating the level's ranking relative to other levels.  # noqa: E501

        :return: The ordinal of this LevelInformation.  # noqa: E501
        :rtype: int
        """
        return self._ordinal

    @ordinal.setter
    def ordinal(self, ordinal):
        """Sets the ordinal of this LevelInformation.

        A value indicating the level's ranking relative to other levels.  # noqa: E501

        :param ordinal: The ordinal of this LevelInformation.  # noqa: E501
        :type: int
        """

        self._ordinal = ordinal

    @property
    def max_bit_rate(self):
        """Gets the max_bit_rate of this LevelInformation.  # noqa: E501


        :return: The max_bit_rate of this LevelInformation.  # noqa: E501
        :rtype: BitRate
        """
        return self._max_bit_rate

    @max_bit_rate.setter
    def max_bit_rate(self, max_bit_rate):
        """Sets the max_bit_rate of this LevelInformation.


        :param max_bit_rate: The max_bit_rate of this LevelInformation.  # noqa: E501
        :type: BitRate
        """

        self._max_bit_rate = max_bit_rate

    @property
    def max_bit_rate_display(self):
        """Gets the max_bit_rate_display of this LevelInformation.  # noqa: E501

        A display value of the `Emby.Media.Model.Types.LevelInformation.MaxBitRate` property.  # noqa: E501

        :return: The max_bit_rate_display of this LevelInformation.  # noqa: E501
        :rtype: str
        """
        return self._max_bit_rate_display

    @max_bit_rate_display.setter
    def max_bit_rate_display(self, max_bit_rate_display):
        """Sets the max_bit_rate_display of this LevelInformation.

        A display value of the `Emby.Media.Model.Types.LevelInformation.MaxBitRate` property.  # noqa: E501

        :param max_bit_rate_display: The max_bit_rate_display of this LevelInformation.  # noqa: E501
        :type: str
        """

        self._max_bit_rate_display = max_bit_rate_display

    @property
    def id(self):
        """Gets the id of this LevelInformation.  # noqa: E501

        A unique identifier.  # noqa: E501

        :return: The id of this LevelInformation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LevelInformation.

        A unique identifier.  # noqa: E501

        :param id: The id of this LevelInformation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def resolution_rates(self):
        """Gets the resolution_rates of this LevelInformation.  # noqa: E501

        Examples for the maximum supported combinations of resolution and rate for this level.  # noqa: E501

        :return: The resolution_rates of this LevelInformation.  # noqa: E501
        :rtype: list[ResolutionWithRate]
        """
        return self._resolution_rates

    @resolution_rates.setter
    def resolution_rates(self, resolution_rates):
        """Sets the resolution_rates of this LevelInformation.

        Examples for the maximum supported combinations of resolution and rate for this level.  # noqa: E501

        :param resolution_rates: The resolution_rates of this LevelInformation.  # noqa: E501
        :type: list[ResolutionWithRate]
        """

        self._resolution_rates = resolution_rates

    @property
    def resolution_rate_strings(self):
        """Gets the resolution_rate_strings of this LevelInformation.  # noqa: E501

        Examples for the maximum supported combinations of resolution and rate for this level as string values.  # noqa: E501

        :return: The resolution_rate_strings of this LevelInformation.  # noqa: E501
        :rtype: list[str]
        """
        return self._resolution_rate_strings

    @resolution_rate_strings.setter
    def resolution_rate_strings(self, resolution_rate_strings):
        """Sets the resolution_rate_strings of this LevelInformation.

        Examples for the maximum supported combinations of resolution and rate for this level as string values.  # noqa: E501

        :param resolution_rate_strings: The resolution_rate_strings of this LevelInformation.  # noqa: E501
        :type: list[str]
        """

        self._resolution_rate_strings = resolution_rate_strings

    @property
    def resolution_rates_display(self):
        """Gets the resolution_rates_display of this LevelInformation.  # noqa: E501

        A single string from the `Emby.Media.Model.Types.LevelInformation.ResolutionRateStrings` list.  # noqa: E501

        :return: The resolution_rates_display of this LevelInformation.  # noqa: E501
        :rtype: str
        """
        return self._resolution_rates_display

    @resolution_rates_display.setter
    def resolution_rates_display(self, resolution_rates_display):
        """Sets the resolution_rates_display of this LevelInformation.

        A single string from the `Emby.Media.Model.Types.LevelInformation.ResolutionRateStrings` list.  # noqa: E501

        :param resolution_rates_display: The resolution_rates_display of this LevelInformation.  # noqa: E501
        :type: str
        """

        self._resolution_rates_display = resolution_rates_display

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LevelInformation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LevelInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UserItemDataDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rating': 'float',
        'played_percentage': 'float',
        'unplayed_item_count': 'int',
        'playback_position_ticks': 'int',
        'play_count': 'int',
        'is_favorite': 'bool',
        'last_played_date': 'datetime',
        'played': 'bool',
        'key': 'str',
        'item_id': 'str',
        'server_id': 'str'
    }

    attribute_map = {
        'rating': 'Rating',
        'played_percentage': 'PlayedPercentage',
        'unplayed_item_count': 'UnplayedItemCount',
        'playback_position_ticks': 'PlaybackPositionTicks',
        'play_count': 'PlayCount',
        'is_favorite': 'IsFavorite',
        'last_played_date': 'LastPlayedDate',
        'played': 'Played',
        'key': 'Key',
        'item_id': 'ItemId',
        'server_id': 'ServerId'
    }

    def __init__(self, rating=None, played_percentage=None, unplayed_item_count=None, playback_position_ticks=None, play_count=None, is_favorite=None, last_played_date=None, played=None, key=None, item_id=None, server_id=None):  # noqa: E501
        """UserItemDataDto - a model defined in Swagger"""  # noqa: E501
        self._rating = None
        self._played_percentage = None
        self._unplayed_item_count = None
        self._playback_position_ticks = None
        self._play_count = None
        self._is_favorite = None
        self._last_played_date = None
        self._played = None
        self._key = None
        self._item_id = None
        self._server_id = None
        self.discriminator = None
        if rating is not None:
            self.rating = rating
        if played_percentage is not None:
            self.played_percentage = played_percentage
        if unplayed_item_count is not None:
            self.unplayed_item_count = unplayed_item_count
        if playback_position_ticks is not None:
            self.playback_position_ticks = playback_position_ticks
        if play_count is not None:
            self.play_count = play_count
        if is_favorite is not None:
            self.is_favorite = is_favorite
        if last_played_date is not None:
            self.last_played_date = last_played_date
        if played is not None:
            self.played = played
        if key is not None:
            self.key = key
        if item_id is not None:
            self.item_id = item_id
        if server_id is not None:
            self.server_id = server_id

    @property
    def rating(self):
        """Gets the rating of this UserItemDataDto.  # noqa: E501

        The rating.  # noqa: E501

        :return: The rating of this UserItemDataDto.  # noqa: E501
        :rtype: float
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this UserItemDataDto.

        The rating.  # noqa: E501

        :param rating: The rating of this UserItemDataDto.  # noqa: E501
        :type: float
        """

        self._rating = rating

    @property
    def played_percentage(self):
        """Gets the played_percentage of this UserItemDataDto.  # noqa: E501

        The played percentage.  # noqa: E501

        :return: The played_percentage of this UserItemDataDto.  # noqa: E501
        :rtype: float
        """
        return self._played_percentage

    @played_percentage.setter
    def played_percentage(self, played_percentage):
        """Sets the played_percentage of this UserItemDataDto.

        The played percentage.  # noqa: E501

        :param played_percentage: The played_percentage of this UserItemDataDto.  # noqa: E501
        :type: float
        """

        self._played_percentage = played_percentage

    @property
    def unplayed_item_count(self):
        """Gets the unplayed_item_count of this UserItemDataDto.  # noqa: E501

        The unplayed item count.  # noqa: E501

        :return: The unplayed_item_count of this UserItemDataDto.  # noqa: E501
        :rtype: int
        """
        return self._unplayed_item_count

    @unplayed_item_count.setter
    def unplayed_item_count(self, unplayed_item_count):
        """Sets the unplayed_item_count of this UserItemDataDto.

        The unplayed item count.  # noqa: E501

        :param unplayed_item_count: The unplayed_item_count of this UserItemDataDto.  # noqa: E501
        :type: int
        """

        self._unplayed_item_count = unplayed_item_count

    @property
    def playback_position_ticks(self):
        """Gets the playback_position_ticks of this UserItemDataDto.  # noqa: E501

        The playback position ticks.  # noqa: E501

        :return: The playback_position_ticks of this UserItemDataDto.  # noqa: E501
        :rtype: int
        """
        return self._playback_position_ticks

    @playback_position_ticks.setter
    def playback_position_ticks(self, playback_position_ticks):
        """Sets the playback_position_ticks of this UserItemDataDto.

        The playback position ticks.  # noqa: E501

        :param playback_position_ticks: The playback_position_ticks of this UserItemDataDto.  # noqa: E501
        :type: int
        """

        self._playback_position_ticks = playback_position_ticks

    @property
    def play_count(self):
        """Gets the play_count of this UserItemDataDto.  # noqa: E501

        The play count.  # noqa: E501

        :return: The play_count of this UserItemDataDto.  # noqa: E501
        :rtype: int
        """
        return self._play_count

    @play_count.setter
    def play_count(self, play_count):
        """Sets the play_count of this UserItemDataDto.

        The play count.  # noqa: E501

        :param play_count: The play_count of this UserItemDataDto.  # noqa: E501
        :type: int
        """

        self._play_count = play_count

    @property
    def is_favorite(self):
        """Gets the is_favorite of this UserItemDataDto.  # noqa: E501

        A value indicating whether this instance is favorite.  # noqa: E501

        :return: The is_favorite of this UserItemDataDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_favorite

    @is_favorite.setter
    def is_favorite(self, is_favorite):
        """Sets the is_favorite of this UserItemDataDto.

        A value indicating whether this instance is favorite.  # noqa: E501

        :param is_favorite: The is_favorite of this UserItemDataDto.  # noqa: E501
        :type: bool
        """

        self._is_favorite = is_favorite

    @property
    def last_played_date(self):
        """Gets the last_played_date of this UserItemDataDto.  # noqa: E501

        The last played date.  # noqa: E501

        :return: The last_played_date of this UserItemDataDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_played_date

    @last_played_date.setter
    def last_played_date(self, last_played_date):
        """Sets the last_played_date of this UserItemDataDto.

        The last played date.  # noqa: E501

        :param last_played_date: The last_played_date of this UserItemDataDto.  # noqa: E501
        :type: datetime
        """

        self._last_played_date = last_played_date

    @property
    def played(self):
        """Gets the played of this UserItemDataDto.  # noqa: E501

        A value indicating whether this `MediaBrowser.Model.Dto.UserItemDataDto` is played.  # noqa: E501

        :return: The played of this UserItemDataDto.  # noqa: E501
        :rtype: bool
        """
        return self._played

    @played.setter
    def played(self, played):
        """Sets the played of this UserItemDataDto.

        A value indicating whether this `MediaBrowser.Model.Dto.UserItemDataDto` is played.  # noqa: E501

        :param played: The played of this UserItemDataDto.  # noqa: E501
        :type: bool
        """

        self._played = played

    @property
    def key(self):
        """Gets the key of this UserItemDataDto.  # noqa: E501

        The key.  # noqa: E501

        :return: The key of this UserItemDataDto.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this UserItemDataDto.

        The key.  # noqa: E501

        :param key: The key of this UserItemDataDto.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def item_id(self):
        """Gets the item_id of this UserItemDataDto.  # noqa: E501

        The item identifier.  # noqa: E501

        :return: The item_id of this UserItemDataDto.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this UserItemDataDto.

        The item identifier.  # noqa: E501

        :param item_id: The item_id of this UserItemDataDto.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def server_id(self):
        """Gets the server_id of this UserItemDataDto.  # noqa: E501

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :return: The server_id of this UserItemDataDto.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this UserItemDataDto.

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :param server_id: The server_id of this UserItemDataDto.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserItemDataDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserItemDataDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class RokuMetadataApiThumbnailInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'position_ticks': 'int',
        'image_tag': 'str'
    }

    attribute_map = {
        'position_ticks': 'PositionTicks',
        'image_tag': 'ImageTag'
    }

    def __init__(self, position_ticks=None, image_tag=None):  # noqa: E501
        """RokuMetadataApiThumbnailInfo - a model defined in Swagger"""  # noqa: E501
        self._position_ticks = None
        self._image_tag = None
        self.discriminator = None
        if position_ticks is not None:
            self.position_ticks = position_ticks
        if image_tag is not None:
            self.image_tag = image_tag

    @property
    def position_ticks(self):
        """Gets the position_ticks of this RokuMetadataApiThumbnailInfo.  # noqa: E501


        :return: The position_ticks of this RokuMetadataApiThumbnailInfo.  # noqa: E501
        :rtype: int
        """
        return self._position_ticks

    @position_ticks.setter
    def position_ticks(self, position_ticks):
        """Sets the position_ticks of this RokuMetadataApiThumbnailInfo.


        :param position_ticks: The position_ticks of this RokuMetadataApiThumbnailInfo.  # noqa: E501
        :type: int
        """

        self._position_ticks = position_ticks

    @property
    def image_tag(self):
        """Gets the image_tag of this RokuMetadataApiThumbnailInfo.  # noqa: E501


        :return: The image_tag of this RokuMetadataApiThumbnailInfo.  # noqa: E501
        :rtype: str
        """
        return self._image_tag

    @image_tag.setter
    def image_tag(self, image_tag):
        """Sets the image_tag of this RokuMetadataApiThumbnailInfo.


        :param image_tag: The image_tag of this RokuMetadataApiThumbnailInfo.  # noqa: E501
        :type: str
        """

        self._image_tag = image_tag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RokuMetadataApiThumbnailInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RokuMetadataApiThumbnailInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ColorFormats(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    UNKNOWN = "Unknown"
    YUV420P = "yuv420p"
    YUYV422 = "yuyv422"
    RGB24 = "rgb24"
    BGR24 = "bgr24"
    YUV422P = "yuv422p"
    YUV444P = "yuv444p"
    YUV410P = "yuv410p"
    YUV411P = "yuv411p"
    GRAY = "gray"
    MONOW = "monow"
    MONOB = "monob"
    PAL8 = "pal8"
    YUVJ420P = "yuvj420p"
    YUVJ422P = "yuvj422p"
    YUVJ444P = "yuvj444p"
    UYVY422 = "uyvy422"
    UYYVYY411 = "uyyvyy411"
    BGR8 = "bgr8"
    BGR4 = "bgr4"
    BGR4_BYTE = "bgr4_byte"
    RGB8 = "rgb8"
    RGB4 = "rgb4"
    RGB4_BYTE = "rgb4_byte"
    NV12 = "nv12"
    NV21 = "nv21"
    ARGB = "argb"
    RGBA = "rgba"
    ABGR = "abgr"
    BGRA = "bgra"
    GRAY16 = "gray16"
    YUV440P = "yuv440p"
    YUVJ440P = "yuvj440p"
    YUVA420P = "yuva420p"
    RGB48 = "rgb48"
    RGB565 = "rgb565"
    RGB555 = "rgb555"
    BGR565 = "bgr565"
    BGR555 = "bgr555"
    VAAPI_MOCO = "vaapi_moco"
    VAAPI_IDCT = "vaapi_idct"
    VAAPI_VLD = "vaapi_vld"
    YUV420P16 = "yuv420p16"
    YUV422P16 = "yuv422p16"
    YUV444P16 = "yuv444p16"
    DXVA2_VLD = "dxva2_vld"
    RGB444 = "rgb444"
    BGR444 = "bgr444"
    YA8 = "ya8"
    BGR48 = "bgr48"
    YUV420P9 = "yuv420p9"
    YUV420P10 = "yuv420p10"
    YUV422P10 = "yuv422p10"
    YUV444P9 = "yuv444p9"
    YUV444P10 = "yuv444p10"
    YUV422P9 = "yuv422p9"
    GBRP = "gbrp"
    GBRP9 = "gbrp9"
    GBRP10 = "gbrp10"
    GBRP16 = "gbrp16"
    YUVA422P = "yuva422p"
    YUVA444P = "yuva444p"
    YUVA420P9 = "yuva420p9"
    YUVA422P9 = "yuva422p9"
    YUVA444P9 = "yuva444p9"
    YUVA420P10 = "yuva420p10"
    YUVA422P10 = "yuva422p10"
    YUVA444P10 = "yuva444p10"
    YUVA420P16 = "yuva420p16"
    YUVA422P16 = "yuva422p16"
    YUVA444P16 = "yuva444p16"
    VDPAU = "vdpau"
    XYZ12 = "xyz12"
    NV16 = "nv16"
    NV20 = "nv20"
    RGBA64 = "rgba64"
    BGRA64 = "bgra64"
    YVYU422 = "yvyu422"
    YA16 = "ya16"
    GBRAP = "gbrap"
    GBRAP16 = "gbrap16"
    QSV = "qsv"
    MMAL = "mmal"
    D3D11VA_VLD = "d3d11va_vld"
    CUDA = "cuda"
    _0RGB = "_0rgb"
    RGB0 = "rgb0"
    _0BGR = "_0bgr"
    BGR0 = "bgr0"
    YUV420P12 = "yuv420p12"
    YUV420P14 = "yuv420p14"
    YUV422P12 = "yuv422p12"
    YUV422P14 = "yuv422p14"
    YUV444P12 = "yuv444p12"
    YUV444P14 = "yuv444p14"
    GBRP12 = "gbrp12"
    GBRP14 = "gbrp14"
    YUVJ411P = "yuvj411p"
    BAYER_BGGR8 = "bayer_bggr8"
    BAYER_RGGB8 = "bayer_rggb8"
    BAYER_GBRG8 = "bayer_gbrg8"
    BAYER_GRBG8 = "bayer_grbg8"
    BAYER_BGGR16 = "bayer_bggr16"
    BAYER_RGGB16 = "bayer_rggb16"
    BAYER_GBRG16 = "bayer_gbrg16"
    BAYER_GRBG16 = "bayer_grbg16"
    XVMC = "xvmc"
    YUV440P10 = "yuv440p10"
    YUV440P12 = "yuv440p12"
    AYUV64 = "ayuv64"
    VIDEOTOOLBOX_VLD = "videotoolbox_vld"
    P010 = "p010"
    GBRAP12 = "gbrap12"
    GBRAP10 = "gbrap10"
    MEDIACODEC = "mediacodec"
    GRAY12 = "gray12"
    GRAY10 = "gray10"
    GRAY14 = "gray14"
    P016 = "p016"
    D3D11 = "d3d11"
    GRAY9 = "gray9"
    GBRPF32 = "gbrpf32"
    GBRAPF32 = "gbrapf32"
    DRM_PRIME = "drm_prime"
    OPENCL = "opencl"
    GRAYF32 = "grayf32"
    YUVA422P12 = "yuva422p12"
    YUVA444P12 = "yuva444p12"
    NV24 = "nv24"
    NV42 = "nv42"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """ColorFormats - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ColorFormats, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ColorFormats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ConditionsPropertyCondition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affected_property_id': 'str',
        'condition_type': 'ConditionsPropertyConditionType',
        'target_property_id': 'str',
        'simple_condition': 'AttributesSimpleCondition',
        'value_condition': 'AttributesValueCondition',
        'value': 'object'
    }

    attribute_map = {
        'affected_property_id': 'AffectedPropertyId',
        'condition_type': 'ConditionType',
        'target_property_id': 'TargetPropertyId',
        'simple_condition': 'SimpleCondition',
        'value_condition': 'ValueCondition',
        'value': 'Value'
    }

    def __init__(self, affected_property_id=None, condition_type=None, target_property_id=None, simple_condition=None, value_condition=None, value=None):  # noqa: E501
        """ConditionsPropertyCondition - a model defined in Swagger"""  # noqa: E501
        self._affected_property_id = None
        self._condition_type = None
        self._target_property_id = None
        self._simple_condition = None
        self._value_condition = None
        self._value = None
        self.discriminator = None
        if affected_property_id is not None:
            self.affected_property_id = affected_property_id
        if condition_type is not None:
            self.condition_type = condition_type
        if target_property_id is not None:
            self.target_property_id = target_property_id
        if simple_condition is not None:
            self.simple_condition = simple_condition
        if value_condition is not None:
            self.value_condition = value_condition
        if value is not None:
            self.value = value

    @property
    def affected_property_id(self):
        """Gets the affected_property_id of this ConditionsPropertyCondition.  # noqa: E501


        :return: The affected_property_id of this ConditionsPropertyCondition.  # noqa: E501
        :rtype: str
        """
        return self._affected_property_id

    @affected_property_id.setter
    def affected_property_id(self, affected_property_id):
        """Sets the affected_property_id of this ConditionsPropertyCondition.


        :param affected_property_id: The affected_property_id of this ConditionsPropertyCondition.  # noqa: E501
        :type: str
        """

        self._affected_property_id = affected_property_id

    @property
    def condition_type(self):
        """Gets the condition_type of this ConditionsPropertyCondition.  # noqa: E501


        :return: The condition_type of this ConditionsPropertyCondition.  # noqa: E501
        :rtype: ConditionsPropertyConditionType
        """
        return self._condition_type

    @condition_type.setter
    def condition_type(self, condition_type):
        """Sets the condition_type of this ConditionsPropertyCondition.


        :param condition_type: The condition_type of this ConditionsPropertyCondition.  # noqa: E501
        :type: ConditionsPropertyConditionType
        """

        self._condition_type = condition_type

    @property
    def target_property_id(self):
        """Gets the target_property_id of this ConditionsPropertyCondition.  # noqa: E501

        The target property name or path.  # noqa: E501

        :return: The target_property_id of this ConditionsPropertyCondition.  # noqa: E501
        :rtype: str
        """
        return self._target_property_id

    @target_property_id.setter
    def target_property_id(self, target_property_id):
        """Sets the target_property_id of this ConditionsPropertyCondition.

        The target property name or path.  # noqa: E501

        :param target_property_id: The target_property_id of this ConditionsPropertyCondition.  # noqa: E501
        :type: str
        """

        self._target_property_id = target_property_id

    @property
    def simple_condition(self):
        """Gets the simple_condition of this ConditionsPropertyCondition.  # noqa: E501


        :return: The simple_condition of this ConditionsPropertyCondition.  # noqa: E501
        :rtype: AttributesSimpleCondition
        """
        return self._simple_condition

    @simple_condition.setter
    def simple_condition(self, simple_condition):
        """Sets the simple_condition of this ConditionsPropertyCondition.


        :param simple_condition: The simple_condition of this ConditionsPropertyCondition.  # noqa: E501
        :type: AttributesSimpleCondition
        """

        self._simple_condition = simple_condition

    @property
    def value_condition(self):
        """Gets the value_condition of this ConditionsPropertyCondition.  # noqa: E501


        :return: The value_condition of this ConditionsPropertyCondition.  # noqa: E501
        :rtype: AttributesValueCondition
        """
        return self._value_condition

    @value_condition.setter
    def value_condition(self, value_condition):
        """Sets the value_condition of this ConditionsPropertyCondition.


        :param value_condition: The value_condition of this ConditionsPropertyCondition.  # noqa: E501
        :type: AttributesValueCondition
        """

        self._value_condition = value_condition

    @property
    def value(self):
        """Gets the value of this ConditionsPropertyCondition.  # noqa: E501

        The value.  # noqa: E501

        :return: The value of this ConditionsPropertyCondition.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ConditionsPropertyCondition.

        The value.  # noqa: E501

        :param value: The value of this ConditionsPropertyCondition.  # noqa: E501
        :type: object
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConditionsPropertyCondition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConditionsPropertyCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TaskInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'state': 'TaskState',
        'current_progress_percentage': 'float',
        'id': 'str',
        'last_execution_result': 'TaskResult',
        'triggers': 'list[TaskTriggerInfo]',
        'description': 'str',
        'category': 'str',
        'is_hidden': 'bool',
        'key': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'state': 'State',
        'current_progress_percentage': 'CurrentProgressPercentage',
        'id': 'Id',
        'last_execution_result': 'LastExecutionResult',
        'triggers': 'Triggers',
        'description': 'Description',
        'category': 'Category',
        'is_hidden': 'IsHidden',
        'key': 'Key'
    }

    def __init__(self, name=None, state=None, current_progress_percentage=None, id=None, last_execution_result=None, triggers=None, description=None, category=None, is_hidden=None, key=None):  # noqa: E501
        """TaskInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._state = None
        self._current_progress_percentage = None
        self._id = None
        self._last_execution_result = None
        self._triggers = None
        self._description = None
        self._category = None
        self._is_hidden = None
        self._key = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if state is not None:
            self.state = state
        if current_progress_percentage is not None:
            self.current_progress_percentage = current_progress_percentage
        if id is not None:
            self.id = id
        if last_execution_result is not None:
            self.last_execution_result = last_execution_result
        if triggers is not None:
            self.triggers = triggers
        if description is not None:
            self.description = description
        if category is not None:
            self.category = category
        if is_hidden is not None:
            self.is_hidden = is_hidden
        if key is not None:
            self.key = key

    @property
    def name(self):
        """Gets the name of this TaskInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this TaskInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskInfo.

        The name.  # noqa: E501

        :param name: The name of this TaskInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def state(self):
        """Gets the state of this TaskInfo.  # noqa: E501


        :return: The state of this TaskInfo.  # noqa: E501
        :rtype: TaskState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TaskInfo.


        :param state: The state of this TaskInfo.  # noqa: E501
        :type: TaskState
        """

        self._state = state

    @property
    def current_progress_percentage(self):
        """Gets the current_progress_percentage of this TaskInfo.  # noqa: E501

        The progress.  # noqa: E501

        :return: The current_progress_percentage of this TaskInfo.  # noqa: E501
        :rtype: float
        """
        return self._current_progress_percentage

    @current_progress_percentage.setter
    def current_progress_percentage(self, current_progress_percentage):
        """Sets the current_progress_percentage of this TaskInfo.

        The progress.  # noqa: E501

        :param current_progress_percentage: The current_progress_percentage of this TaskInfo.  # noqa: E501
        :type: float
        """

        self._current_progress_percentage = current_progress_percentage

    @property
    def id(self):
        """Gets the id of this TaskInfo.  # noqa: E501

        The id.  # noqa: E501

        :return: The id of this TaskInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TaskInfo.

        The id.  # noqa: E501

        :param id: The id of this TaskInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def last_execution_result(self):
        """Gets the last_execution_result of this TaskInfo.  # noqa: E501


        :return: The last_execution_result of this TaskInfo.  # noqa: E501
        :rtype: TaskResult
        """
        return self._last_execution_result

    @last_execution_result.setter
    def last_execution_result(self, last_execution_result):
        """Sets the last_execution_result of this TaskInfo.


        :param last_execution_result: The last_execution_result of this TaskInfo.  # noqa: E501
        :type: TaskResult
        """

        self._last_execution_result = last_execution_result

    @property
    def triggers(self):
        """Gets the triggers of this TaskInfo.  # noqa: E501

        The triggers.  # noqa: E501

        :return: The triggers of this TaskInfo.  # noqa: E501
        :rtype: list[TaskTriggerInfo]
        """
        return self._triggers

    @triggers.setter
    def triggers(self, triggers):
        """Sets the triggers of this TaskInfo.

        The triggers.  # noqa: E501

        :param triggers: The triggers of this TaskInfo.  # noqa: E501
        :type: list[TaskTriggerInfo]
        """

        self._triggers = triggers

    @property
    def description(self):
        """Gets the description of this TaskInfo.  # noqa: E501

        The description.  # noqa: E501

        :return: The description of this TaskInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TaskInfo.

        The description.  # noqa: E501

        :param description: The description of this TaskInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def category(self):
        """Gets the category of this TaskInfo.  # noqa: E501

        The category.  # noqa: E501

        :return: The category of this TaskInfo.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this TaskInfo.

        The category.  # noqa: E501

        :param category: The category of this TaskInfo.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def is_hidden(self):
        """Gets the is_hidden of this TaskInfo.  # noqa: E501

        A value indicating whether this instance is hidden.  # noqa: E501

        :return: The is_hidden of this TaskInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """Sets the is_hidden of this TaskInfo.

        A value indicating whether this instance is hidden.  # noqa: E501

        :param is_hidden: The is_hidden of this TaskInfo.  # noqa: E501
        :type: bool
        """

        self._is_hidden = is_hidden

    @property
    def key(self):
        """Gets the key of this TaskInfo.  # noqa: E501

        The key.  # noqa: E501

        :return: The key of this TaskInfo.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this TaskInfo.

        The key.  # noqa: E501

        :param key: The key of this TaskInfo.  # noqa: E501
        :type: str
        """

        self._key = key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class RunUICommand(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page_id': 'str',
        'command_id': 'str',
        'data': 'str',
        'item_id': 'str',
        'client_locale': 'str'
    }

    attribute_map = {
        'page_id': 'PageId',
        'command_id': 'CommandId',
        'data': 'Data',
        'item_id': 'ItemId',
        'client_locale': 'ClientLocale'
    }

    def __init__(self, page_id=None, command_id=None, data=None, item_id=None, client_locale=None):  # noqa: E501
        """RunUICommand - a model defined in Swagger"""  # noqa: E501
        self._page_id = None
        self._command_id = None
        self._data = None
        self._item_id = None
        self._client_locale = None
        self.discriminator = None
        if page_id is not None:
            self.page_id = page_id
        if command_id is not None:
            self.command_id = command_id
        if data is not None:
            self.data = data
        if item_id is not None:
            self.item_id = item_id
        if client_locale is not None:
            self.client_locale = client_locale

    @property
    def page_id(self):
        """Gets the page_id of this RunUICommand.  # noqa: E501


        :return: The page_id of this RunUICommand.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this RunUICommand.


        :param page_id: The page_id of this RunUICommand.  # noqa: E501
        :type: str
        """

        self._page_id = page_id

    @property
    def command_id(self):
        """Gets the command_id of this RunUICommand.  # noqa: E501


        :return: The command_id of this RunUICommand.  # noqa: E501
        :rtype: str
        """
        return self._command_id

    @command_id.setter
    def command_id(self, command_id):
        """Sets the command_id of this RunUICommand.


        :param command_id: The command_id of this RunUICommand.  # noqa: E501
        :type: str
        """

        self._command_id = command_id

    @property
    def data(self):
        """Gets the data of this RunUICommand.  # noqa: E501


        :return: The data of this RunUICommand.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this RunUICommand.


        :param data: The data of this RunUICommand.  # noqa: E501
        :type: str
        """

        self._data = data

    @property
    def item_id(self):
        """Gets the item_id of this RunUICommand.  # noqa: E501


        :return: The item_id of this RunUICommand.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this RunUICommand.


        :param item_id: The item_id of this RunUICommand.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def client_locale(self):
        """Gets the client_locale of this RunUICommand.  # noqa: E501


        :return: The client_locale of this RunUICommand.  # noqa: E501
        :rtype: str
        """
        return self._client_locale

    @client_locale.setter
    def client_locale(self, client_locale):
        """Sets the client_locale of this RunUICommand.


        :param client_locale: The client_locale of this RunUICommand.  # noqa: E501
        :type: str
        """

        self._client_locale = client_locale

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RunUICommand, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunUICommand):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class SyncServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_sync_by_targetid_items(self, target_id, **kwargs):  # noqa: E501
        """Cancels items from a sync target  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sync_by_targetid_items(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :param str item_ids: ItemIds
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_sync_by_targetid_items_with_http_info(target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_sync_by_targetid_items_with_http_info(target_id, **kwargs)  # noqa: E501
            return data

    def delete_sync_by_targetid_items_with_http_info(self, target_id, **kwargs):  # noqa: E501
        """Cancels items from a sync target  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sync_by_targetid_items_with_http_info(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :param str item_ids: ItemIds
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['target_id', 'item_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sync_by_targetid_items" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'target_id' is set
        if ('target_id' not in params or
                params['target_id'] is None):
            raise ValueError("Missing the required parameter `target_id` when calling `delete_sync_by_targetid_items`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'target_id' in params:
            path_params['TargetId'] = params['target_id']  # noqa: E501

        query_params = []
        if 'item_ids' in params:
            query_params.append(('ItemIds', params['item_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/{TargetId}/Items', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_sync_jobitems_by_id(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sync_jobitems_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_sync_jobitems_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_sync_jobitems_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_sync_jobitems_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sync_jobitems_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sync_jobitems_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_sync_jobitems_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_sync_jobs_by_id(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sync_jobs_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_sync_jobs_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_sync_jobs_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_sync_jobs_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_sync_jobs_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_sync_jobs_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_sync_jobs_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Jobs/{Id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_items_ready(self, target_id, **kwargs):  # noqa: E501
        """Gets ready to download sync items.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_items_ready(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :return: list[SyncedItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_items_ready_with_http_info(target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_items_ready_with_http_info(target_id, **kwargs)  # noqa: E501
            return data

    def get_sync_items_ready_with_http_info(self, target_id, **kwargs):  # noqa: E501
        """Gets ready to download sync items.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_items_ready_with_http_info(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :return: list[SyncedItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['target_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_items_ready" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'target_id' is set
        if ('target_id' not in params or
                params['target_id'] is None):
            raise ValueError("Missing the required parameter `target_id` when calling `get_sync_items_ready`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'target_id' in params:
            query_params.append(('TargetId', params['target_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Items/Ready', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SyncedItem]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_jobitems(self, target_id, **kwargs):  # noqa: E501
        """Gets sync job items.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobitems(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :return: QueryResultSyncJobItem
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_jobitems_with_http_info(target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_jobitems_with_http_info(target_id, **kwargs)  # noqa: E501
            return data

    def get_sync_jobitems_with_http_info(self, target_id, **kwargs):  # noqa: E501
        """Gets sync job items.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobitems_with_http_info(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :return: QueryResultSyncJobItem
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['target_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_jobitems" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'target_id' is set
        if ('target_id' not in params or
                params['target_id'] is None):
            raise ValueError("Missing the required parameter `target_id` when calling `get_sync_jobitems`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'target_id' in params:
            query_params.append(('TargetId', params['target_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultSyncJobItem',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_jobitems_by_id_additionalfiles(self, id, name, **kwargs):  # noqa: E501
        """Gets a sync job item file  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobitems_by_id_additionalfiles(id, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :param str name: Name (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_jobitems_by_id_additionalfiles_with_http_info(id, name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_jobitems_by_id_additionalfiles_with_http_info(id, name, **kwargs)  # noqa: E501
            return data

    def get_sync_jobitems_by_id_additionalfiles_with_http_info(self, id, name, **kwargs):  # noqa: E501
        """Gets a sync job item file  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobitems_by_id_additionalfiles_with_http_info(id, name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :param str name: Name (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_jobitems_by_id_additionalfiles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_sync_jobitems_by_id_additionalfiles`")  # noqa: E501
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_sync_jobitems_by_id_additionalfiles`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'name' in params:
            query_params.append(('Name', params['name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/AdditionalFiles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_jobitems_by_id_file(self, id, **kwargs):  # noqa: E501
        """Gets a sync job item file  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobitems_by_id_file(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_jobitems_by_id_file_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_jobitems_by_id_file_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_sync_jobitems_by_id_file_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a sync job item file  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobitems_by_id_file_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_jobitems_by_id_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_sync_jobitems_by_id_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/File', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_jobs(self, **kwargs):  # noqa: E501
        """Gets sync jobs.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: QueryResultSyncJob
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_jobs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_jobs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_sync_jobs_with_http_info(self, **kwargs):  # noqa: E501
        """Gets sync jobs.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: QueryResultSyncJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_jobs" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultSyncJob',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_jobs_by_id(self, id, **kwargs):  # noqa: E501
        """Gets a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobs_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: SyncJob
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_jobs_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_jobs_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_sync_jobs_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_jobs_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: SyncJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_jobs_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_sync_jobs_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Jobs/{Id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SyncJob',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_options(self, user_id, **kwargs):  # noqa: E501
        """Gets a list of available sync targets.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_options(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: UserId (required)
        :param str item_ids: ItemIds
        :param str parent_id: ParentId
        :param str target_id: TargetId
        :param SyncCategory category: Category
        :return: SyncDialogOptions
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_options_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_options_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_sync_options_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Gets a list of available sync targets.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_options_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: UserId (required)
        :param str item_ids: ItemIds
        :param str parent_id: ParentId
        :param str target_id: TargetId
        :param SyncCategory category: Category
        :return: SyncDialogOptions
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'item_ids', 'parent_id', 'target_id', 'category']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_options" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_sync_options`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501
        if 'item_ids' in params:
            query_params.append(('ItemIds', params['item_ids']))  # noqa: E501
        if 'parent_id' in params:
            query_params.append(('ParentId', params['parent_id']))  # noqa: E501
        if 'target_id' in params:
            query_params.append(('TargetId', params['target_id']))  # noqa: E501
        if 'category' in params:
            query_params.append(('Category', params['category']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Options', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SyncDialogOptions',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sync_targets(self, user_id, **kwargs):  # noqa: E501
        """Gets a list of available sync targets.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_targets(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: UserId (required)
        :return: list[SyncTarget]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sync_targets_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sync_targets_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_sync_targets_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Gets a list of available sync targets.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sync_targets_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: UserId (required)
        :return: list[SyncTarget]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sync_targets" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_sync_targets`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Targets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SyncTarget]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_sync_jobitems_by_id_file(self, id, **kwargs):  # noqa: E501
        """Gets a sync job item file  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_sync_jobitems_by_id_file(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_sync_jobitems_by_id_file_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_sync_jobitems_by_id_file_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def head_sync_jobitems_by_id_file_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a sync job item file  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_sync_jobitems_by_id_file_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_sync_jobitems_by_id_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `head_sync_jobitems_by_id_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/File', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_by_itemid_status(self, body, item_id, **kwargs):  # noqa: E501
        """Gets sync status for an item.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_by_itemid_status(body, item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncedItemProgress body: SyncedItemProgress:  (required)
        :param str item_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_by_itemid_status_with_http_info(body, item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_by_itemid_status_with_http_info(body, item_id, **kwargs)  # noqa: E501
            return data

    def post_sync_by_itemid_status_with_http_info(self, body, item_id, **kwargs):  # noqa: E501
        """Gets sync status for an item.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_by_itemid_status_with_http_info(body, item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncedItemProgress body: SyncedItemProgress:  (required)
        :param str item_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_by_itemid_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sync_by_itemid_status`")  # noqa: E501
        # verify the required parameter 'item_id' is set
        if ('item_id' not in params or
                params['item_id'] is None):
            raise ValueError("Missing the required parameter `item_id` when calling `post_sync_by_itemid_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'item_id' in params:
            path_params['ItemId'] = params['item_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/{ItemId}/Status', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_by_targetid_items_delete(self, target_id, **kwargs):  # noqa: E501
        """Cancels items from a sync target  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_by_targetid_items_delete(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :param str item_ids: ItemIds
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_by_targetid_items_delete_with_http_info(target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_by_targetid_items_delete_with_http_info(target_id, **kwargs)  # noqa: E501
            return data

    def post_sync_by_targetid_items_delete_with_http_info(self, target_id, **kwargs):  # noqa: E501
        """Cancels items from a sync target  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_by_targetid_items_delete_with_http_info(target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str target_id: TargetId (required)
        :param str item_ids: ItemIds
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['target_id', 'item_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_by_targetid_items_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'target_id' is set
        if ('target_id' not in params or
                params['target_id'] is None):
            raise ValueError("Missing the required parameter `target_id` when calling `post_sync_by_targetid_items_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'target_id' in params:
            path_params['TargetId'] = params['target_id']  # noqa: E501

        query_params = []
        if 'item_ids' in params:
            query_params.append(('ItemIds', params['item_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/{TargetId}/Items/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_data(self, body, target_id, **kwargs):  # noqa: E501
        """Syncs data between device and server  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_data(body, target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncDataRequest body: SyncDataRequest:  (required)
        :param str target_id: TargetId (required)
        :return: SyncDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_data_with_http_info(body, target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_data_with_http_info(body, target_id, **kwargs)  # noqa: E501
            return data

    def post_sync_data_with_http_info(self, body, target_id, **kwargs):  # noqa: E501
        """Syncs data between device and server  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_data_with_http_info(body, target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncDataRequest body: SyncDataRequest:  (required)
        :param str target_id: TargetId (required)
        :return: SyncDataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'target_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sync_data`")  # noqa: E501
        # verify the required parameter 'target_id' is set
        if ('target_id' not in params or
                params['target_id'] is None):
            raise ValueError("Missing the required parameter `target_id` when calling `post_sync_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'target_id' in params:
            query_params.append(('TargetId', params['target_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SyncDataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_items_cancel(self, **kwargs):  # noqa: E501
        """Cancels items from a sync target  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_items_cancel(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_ids: ItemIds
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_items_cancel_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_items_cancel_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_sync_items_cancel_with_http_info(self, **kwargs):  # noqa: E501
        """Cancels items from a sync target  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_items_cancel_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_ids: ItemIds
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_items_cancel" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'item_ids' in params:
            query_params.append(('ItemIds', params['item_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Items/Cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobitems_by_id_delete(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobitems_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobitems_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_sync_jobitems_by_id_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobitems_by_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sync_jobitems_by_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobitems_by_id_enable(self, id, **kwargs):  # noqa: E501
        """Enables a cancelled or queued sync job item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_enable(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobitems_by_id_enable_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobitems_by_id_enable_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_sync_jobitems_by_id_enable_with_http_info(self, id, **kwargs):  # noqa: E501
        """Enables a cancelled or queued sync job item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_enable_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobitems_by_id_enable" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sync_jobitems_by_id_enable`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/Enable', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobitems_by_id_markforremoval(self, id, **kwargs):  # noqa: E501
        """Marks a job item for removal  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_markforremoval(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobitems_by_id_markforremoval_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobitems_by_id_markforremoval_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_sync_jobitems_by_id_markforremoval_with_http_info(self, id, **kwargs):  # noqa: E501
        """Marks a job item for removal  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_markforremoval_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobitems_by_id_markforremoval" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sync_jobitems_by_id_markforremoval`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/MarkForRemoval', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobitems_by_id_transferred(self, id, **kwargs):  # noqa: E501
        """Reports that a sync job item has successfully been transferred.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_transferred(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobitems_by_id_transferred_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobitems_by_id_transferred_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_sync_jobitems_by_id_transferred_with_http_info(self, id, **kwargs):  # noqa: E501
        """Reports that a sync job item has successfully been transferred.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_transferred_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobitems_by_id_transferred" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sync_jobitems_by_id_transferred`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/Transferred', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobitems_by_id_unmarkforremoval(self, id, **kwargs):  # noqa: E501
        """Unmarks a job item for removal  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_unmarkforremoval(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobitems_by_id_unmarkforremoval_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobitems_by_id_unmarkforremoval_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_sync_jobitems_by_id_unmarkforremoval_with_http_info(self, id, **kwargs):  # noqa: E501
        """Unmarks a job item for removal  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobitems_by_id_unmarkforremoval_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobitems_by_id_unmarkforremoval" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sync_jobitems_by_id_unmarkforremoval`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/JobItems/{Id}/UnmarkForRemoval', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobs(self, body, **kwargs):  # noqa: E501
        """Gets sync jobs.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobs(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncJobRequest body: SyncJobRequest:  (required)
        :return: SyncJobCreationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobs_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobs_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_sync_jobs_with_http_info(self, body, **kwargs):  # noqa: E501
        """Gets sync jobs.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobs_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncJobRequest body: SyncJobRequest:  (required)
        :return: SyncJobCreationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sync_jobs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Jobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SyncJobCreationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobs_by_id(self, body, id, **kwargs):  # noqa: E501
        """Updates a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobs_by_id(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncJob body: SyncJob:  (required)
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobs_by_id_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobs_by_id_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_sync_jobs_by_id_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Updates a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobs_by_id_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SyncJob body: SyncJob:  (required)
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobs_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sync_jobs_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sync_jobs_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Jobs/{Id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_jobs_by_id_delete(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobs_by_id_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_jobs_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_jobs_by_id_delete_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def post_sync_jobs_by_id_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancels a sync job.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_jobs_by_id_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_jobs_by_id_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_sync_jobs_by_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/Jobs/{Id}/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_sync_offlineactions(self, body, **kwargs):  # noqa: E501
        """Reports an action that occurred while offline.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_offlineactions(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[UserAction] body: List`1:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_sync_offlineactions_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_sync_offlineactions_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_sync_offlineactions_with_http_info(self, body, **kwargs):  # noqa: E501
        """Reports an action that occurred while offline.  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_sync_offlineactions_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[UserAction] body: List`1:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_sync_offlineactions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_sync_offlineactions`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Sync/OfflineActions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
